==> datasurface-0.0.19-py3-none-any.whl: tests/actionHandlerResources/step2/head_EU/eco.py <==
"""
// Copyright (c) William Newport
// SPDX-License-Identifier: BUSL-1.1
"""

from datasurface.platforms.aws.AmazonAWS import AmazonAWSDataPlatform
from datasurface.platforms.azure.Azure import AzureDataplatform, AzureKeyVaultCredential
from datasurface.md.Documentation import PlainTextDocumentation
from datasurface.md.GitOps import GitHubRepository
from datasurface.md.Governance import CloudVendor, DataPlatformCICDExecutor, DefaultDataPlatform, Ecosystem, GovernanceZone, \
    GovernanceZoneDeclaration, InfraStructureLocationPolicy, \
    InfrastructureLocation, InfrastructureVendor, TeamDeclaration

# Base branch for step 1, define an Ecosystem, data platforms, infrastructure vendors/locations and 3 Governance Zones


def createEcosystem() -> Ecosystem:
    e: Ecosystem = Ecosystem(
        "Test",
        GitHubRepository("billynewport/test_step1", "main"),
        DefaultDataPlatform(
            AzureDataplatform(
                "Azure Platform",
                PlainTextDocumentation("Test"),
                DataPlatformCICDExecutor(GitHubRepository("owner/repo", "branch")),
                AzureKeyVaultCredential("vault", "maincred"))),
        AmazonAWSDataPlatform("AWS Platform", PlainTextDocumentation("Test"), DataPlatformCICDExecutor(GitHubRepository("owner/repo", "branch"))),

        GovernanceZoneDeclaration("USA", GitHubRepository("billynewport/test_step1", "USAmain")),
        GovernanceZoneDeclaration("EU", GitHubRepository("billynewport/test_step1", "EUmain")),
        GovernanceZoneDeclaration("UK", GitHubRepository("billynewport/test_step1", "UKmain")),

        # Infra Vendors and locations
        InfrastructureVendor(
            "AWS",
            CloudVendor.AWS,
            PlainTextDocumentation("Amazon AWS"),
            InfrastructureLocation(
                "USA",
                InfrastructureLocation("us-east-1"),  # Virginia
                InfrastructureLocation("us-west-1")),
            InfrastructureLocation(
                "UK",
                InfrastructureLocation("eu-west-1"),  # Ireland
                InfrastructureLocation("eu-west-2")),  # London
            InfrastructureLocation(
                "EU",
                InfrastructureLocation("eu-central-1"),  # Frankfurt
                InfrastructureLocation("eu-west-3"))),

        InfrastructureVendor(
            "Azure",
            CloudVendor.AZURE,
            PlainTextDocumentation("Microsoft Azure"),
            InfrastructureLocation(
                "USA",
                InfrastructureLocation(
                    "Central",
                    InfrastructureLocation("Central US"),  # Iowa
                    InfrastructureLocation("North Central US"),  # Illinois
                    InfrastructureLocation("South Central US"),  # Texas
                    InfrastructureLocation("West Central US")),  # Wyoming
                InfrastructureLocation(
                    "East",
                    InfrastructureLocation("East US"),  # Virginia
                    InfrastructureLocation("East US 2"),  # Virginia
                    InfrastructureLocation("East US 3")),  # Georgia
                InfrastructureLocation(
                    "West",
                    InfrastructureLocation("West US"),  # California
                    InfrastructureLocation("West US 2"),  # Washington
                    InfrastructureLocation("West US 3"))))  # Arizona
        )

    # Add the EU GZ and its policies limiting locations to EU only
    gzEU: GovernanceZone = e.getZoneOrThrow("EU")

    # Enumerate all EU locations for AWS
    allEULocations: set[InfrastructureLocation] = e.getLocationOrThrow("AWS", ["EU"]).getEveryChildLocation()

    gzEU.add(
        InfraStructureLocationPolicy("EU Only", PlainTextDocumentation("Test"), allEULocations),
        TeamDeclaration("ParisTeam", GitHubRepository("billynewport/test_step1", "ParisMain"))
    )

    return e

==> datasurface-0.0.32-py3-none-any.whl: tests/actionHandlerResources/step2/head_EU/eco.py <==
"""
// Copyright (c) William Newport
// SPDX-License-Identifier: BUSL-1.1
"""

from datasurface.md.documentation import PlainTextDocumentation
from datasurface.md.repo import GitHubRepository
from datasurface.md import LocationKey
from datasurface.md import CloudVendor, DefaultDataPlatform, Ecosystem, GovernanceZone, \
    GovernanceZoneDeclaration, InfraStructureLocationPolicy, \
    InfrastructureLocation, InfrastructureVendor, TeamDeclaration, DataPlatformKey
from datasurface.platforms.legacy import LegacyDataPlatform

# Base branch for step 1, define an Ecosystem, data platforms, infrastructure vendors/locations and 3 Governance Zones


def createEcosystem() -> Ecosystem:
    e: Ecosystem = Ecosystem(
        "Test",
        GitHubRepository("billynewport/test_step1", "main"),
        LegacyDataPlatform(
            "Azure Platform",
            PlainTextDocumentation("Test")),
        DefaultDataPlatform(DataPlatformKey("Azure Platform")),
        LegacyDataPlatform("AWS Platform", PlainTextDocumentation("Test")),

        GovernanceZoneDeclaration("USA", GitHubRepository("billynewport/test_step1", "USAmain")),
        GovernanceZoneDeclaration("EU", GitHubRepository("billynewport/test_step1", "EUmain")),
        GovernanceZoneDeclaration("UK", GitHubRepository("billynewport/test_step1", "UKmain")),

        # Infra Vendors and locations
        InfrastructureVendor(
            "AWS",
            CloudVendor.AWS,
            PlainTextDocumentation("Amazon AWS"),
            InfrastructureLocation(
                "USA",
                InfrastructureLocation("us-east-1"),  # Virginia
                InfrastructureLocation("us-west-1")),
            InfrastructureLocation(
                "UK",
                InfrastructureLocation("eu-west-1"),  # Ireland
                InfrastructureLocation("eu-west-2")),  # London
            InfrastructureLocation(
                "EU",
                InfrastructureLocation("eu-central-1"),  # Frankfurt
                InfrastructureLocation("eu-west-3"))),

        InfrastructureVendor(
            "Azure",
            CloudVendor.AZURE,
            PlainTextDocumentation("Microsoft Azure"),
            InfrastructureLocation(
                "USA",
                InfrastructureLocation(
                    "Central",
                    InfrastructureLocation("Central US"),  # Iowa
                    InfrastructureLocation("North Central US"),  # Illinois
                    InfrastructureLocation("South Central US"),  # Texas
                    InfrastructureLocation("West Central US")),  # Wyoming
                InfrastructureLocation(
                    "East",
                    InfrastructureLocation("East US"),  # Virginia
                    InfrastructureLocation("East US 2"),  # Virginia
                    InfrastructureLocation("East US 3")),  # Georgia
                InfrastructureLocation(
                    "West",
                    InfrastructureLocation("West US"),  # California
                    InfrastructureLocation("West US 2"),  # Washington
                    InfrastructureLocation("West US 3"))))  # Arizona
        )

    # Add the EU GZ and its policies limiting locations to EU only
    gzEU: GovernanceZone = e.getZoneOrThrow("EU")

    # Enumerate all EU locations for AWS
    allEULocations: set[InfrastructureLocation] = e.getLocationOrThrow("AWS", ["EU"]).getEveryChildLocation()
    allEUKeys: set[LocationKey] = {LocationKey("AWS:EU/" + loc.name) for loc in allEULocations}

    gzEU.add(
        InfraStructureLocationPolicy("EU Only", PlainTextDocumentation("Test"), allEUKeys),
        TeamDeclaration("ParisTeam", GitHubRepository("billynewport/test_step1", "ParisMain"))
    )

    return e
